@@ -1,17 +1,15 @@
 package FusionInventory::Agent::Storage;
         
-use Storable;
-
 use strict;
 use warnings;
 
 use Config;
-
 use File::Glob ':glob';
+use Storable;
 
 my $lock :shared;
 
-use Data::Dumper;
+use English qw(-no_match_vars);
 
 =head1 NAME
 
@@ -21,7 +19,7 @@ on the caller module name.
 
 =head1 SYNOPSIS
 
-  my $storage = new FusionInventory::Agent::Storage({
+  my $storage = FusionInventory::Agent::Storage->new({
       target => {
           vardir => $ARGV[0],
       }
@@ -47,22 +45,27 @@ Create the object
 
 =cut
 sub new {
-    my ( undef, $params ) = @_;
+    my ( $class, $params ) = @_;
 
     my $self = {};
 
     if ($Config{usethreads}) {
-        if (!(eval "use threads;1;" && eval "use threads::shared;1;")) {
-            print "[error]Failed to use threads!\n";
+        eval {
+            require threads;
+            require threads::shared;
+        };
+        if ($EVAL_ERROR) {
+            print "[error]Failed to use threads!\n"; 
         }
     }
 
     my $config = $self->{config} = $params->{config};
     my $target = $self->{target} = $params->{target};
+    $self->{logger} = $params->{logger};
 
     $self->{vardir} = $target->{vardir};
 
-    bless $self;
+    bless $self, $class;
 }
 
 sub getFileName {
@@ -105,8 +108,7 @@ sub getFilePath {
     my $extension = '';
     if ($idx) {
         if ($idx !~ /^\d+$/) {
-            print "[fault] idx must be an integer!\n";
-            die;
+            $self->{logger}->fault("[fault] idx must be an integer!\n");
         } 
         $extension = '.'.$idx;
     }
@@ -132,7 +134,7 @@ sub getFileDir {
     } elsif ($config) {
         $dirName = $config->{'basevardir'};
     } else {
-        die;
+        $self->{logger}->fault('no target nor config');
     }
 
     return $dirName;
@@ -144,8 +146,8 @@ sub getFileDir {
 =item save({ data => $date, idx => $ref })
 
 Save the reference.
-$idx is an integer. You can use if if you want to save more than one file for the
-module. This number will be add at the of the file
+$idx is an integer. You can use it if you want to save more than one file for the
+module. This number will be added at the of the file.
 
 =cut
 sub save {
@@ -159,19 +161,18 @@ sub save {
     my $filePath = $self->getFilePath({ idx => $idx });
 #    print "[storage]save data in:". $filePath."\n";
 
-    my $isWindows = $^O =~ /^^MSWin/;
-    my $oldMask = umask();
+    my $oldMask;
 
-    if (!$isWindows) {
-        umask(077) or die "Can't restrict access to $filePath\n";
-    } else {
-        print "TODO, restrict access to temp file!\n";
-}
+    if ($OSNAME ne 'MSWin32') {
+        $oldMask = umask();
+        umask(oct(77));
+    }
+    # TODO: restrict access to temp file under windows
 
-	store ($data, $filePath) or warn;
+    store ($data, $filePath) or warn;
     
-    if (!$isWindows) {
-        umask($oldMask) or die "Can't restore old mask\n";
+    if ($OSNAME ne 'MSWin32') {
+        umask $oldMask;
     }
 
 }
@@ -194,8 +195,8 @@ sub restore {
     my $idx = $params->{idx};
 
     my $filePath = $self->getFilePath({
-            module => $module,
-            idx => $idx
+        module => $module,
+        idx => $idx
     });
     #print "[storage]restore data from: $filePath\n";
 
