@@ -3,10 +3,10 @@ package FusionInventory::Agent::Task;
 use strict;
 use warnings;
 
-use English;
+use English qw(-no_match_vars);
 
 sub new {
-    my (undef, $params) = @_;
+    my ($class, $params) = @_;
 
     my $self = {};
 
@@ -15,16 +15,17 @@ sub new {
     $self->{target} = $params->{target};
 
     $self->{module} = $params->{module};
-    $self->{name} = $params->{name};
+
 
     my $config = $self->{config};
     my $logger = $self->{logger};
     my $module = $self->{module};
-    my $name = $self->{name};
 
-    return if $config->{$name};
 
-    bless $self;
+    return if $config->{'no-'.lc($self->{module})};
+
+
+    bless $self, $class;
     if (!$self->isModInstalled()) {
         $logger->info("Module FusionInventory::Agent::Task::$module is not installed.");
         return;
@@ -54,14 +55,17 @@ sub run {
     my $target = $self->{target};
     
     my $module = $self->{module};
-    my $name = $self->{name};
+
 
     my $cmd;
-    $cmd .= $EXECUTABLE_NAME; # The Perl binary path
-    $cmd .= "  -Ilib" if $config->{devlib};
-    $cmd .= " -MFusionInventory::Agent::Task::".$module;
-    $cmd .= " -e 'FusionInventory::Agent::Task::".$module."::main();' --";
-    $cmd .= " ".$target->{vardir};
+    $cmd .= "\"$EXECUTABLE_NAME\""; # The Perl binary path
+    $cmd .= " -e \"";
+    $cmd .= "\@INC=qw(";
+    $cmd .= $_." " foreach (@INC);
+    $cmd .= "); ";
+    $cmd .= "eval 'use FusionInventory::Agent::Task::$module;'; ";
+    $cmd .= "FusionInventory::Agent::Task::".$module."::main();\" --";
+    $cmd .= " \"".$target->{vardir}."\"";
 
     $logger->debug("cmd is: '$cmd'");
     system($cmd);
