@@ -55,6 +55,7 @@ sub isInventoryEnabled {
 sub doInventory {
     my $params = shift;
     my $inventory = $params->{inventory};
+    my $logger = $params->{logger};
 
     # return immediatly if vm type has already been found
     return if $inventory->{h}{CONTENT}{HARDWARE}{VMSYSTEM}->[0] ne "Physical";
@@ -112,8 +113,8 @@ sub doInventory {
                 }
             }
             close $handle;
-        } else {
-            warn "Can't open /proc/modules: $ERRNO";
+#        } else {
+#            $logger->debug("Can't open /proc/modules: $ERRNO");
         }
     }
 
@@ -162,8 +163,8 @@ sub doInventory {
                 }
             }
             close($handle);
-        } else {
-            warn "Can't open /var/log/dmesg: $ERRNO";
+#        } else {
+#            $logger->debug("Can't open /var/log/dmesg: $ERRNO");
         }
     }
 
@@ -180,8 +181,8 @@ sub doInventory {
                 }
             }
             close $handle;
-        } else {
-            warn "Can't run $dmesg: $ERRNO";
+#        } else {
+#            $logger->debug("Can't run $dmesg: $ERRNO");
         }
     }
 
@@ -198,7 +199,7 @@ sub doInventory {
             }
             close $handle;
 #        } else {
-#            warn "Can't open /proc/scsi/scsi: $ERRNO";
+#            $logger->debug("Can't open /proc/scsi/scsi: $ERRNO");
         }
     }
 
